﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Globalization;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using HeuristicLab.Core.Views;
using HeuristicLab.MainForm;
using HeuristicLab.MainForm.WindowsForms;

namespace HeuristicLab.Problems.DataAnalysis.Views {
  [View("Interval Constraint Detail View")]
  [Content(typeof(IntervalConstraint), true)]
  public partial class IntervalConstraintView : ItemView {

    public new IntervalConstraint Content {
      get { return (IntervalConstraint)base.Content; }
      set { base.Content = value; }
    }
    public IntervalConstraintView() {
      InitializeComponent();
      expressionInput.ReadOnly = true;
      definitionInput.ReadOnly = true;
      derivationInput.ReadOnly = true;
    }

    protected override void RegisterContentEvents() {
      base.RegisterContentEvents();
      Content.Changed += new EventHandler(Content_Changed);
    }

    protected override void DeregisterContentEvents() {
      base.DeregisterContentEvents();
      Content.Changed -= new EventHandler(Content_Changed);
    }

    private void Content_Changed(object sender, EventArgs e) {
      UpdateControls();
    }

    protected override void OnContentChanged() {
      base.OnContentChanged();
      UpdateControls();
      UpdateValues();
    }

    protected override void SetEnabledStateOfControls() {
      base.SetEnabledStateOfControls();
      lowerboundInput.Enabled = Content != null && !Locked;
    }

    private void UpdateControls() {
      if (Content == null) {
        expressionInput.Text = string.Empty;
        definitionInput.Text = string.Empty;
        lowerboundInput.Text = string.Empty;
        upperboundInput.Text = string.Empty;
        lowerCombo.SelectedItem = null;
        lowerCombo.SelectedText = "--Nothing set--";
        upperCombo.SelectedItem = null;
        upperCombo.SelectedText = "--Nothing set--";
      } else {
        expressionInput.Text = Content.Expression;
        definitionInput.Text = Content.Definition;
        lowerboundInput.Text = Content.Interval.LowerBound.ToString(CultureInfo.InvariantCulture);
        upperboundInput.Text = Content.Interval.UpperBound.ToString(CultureInfo.InvariantCulture);
        lowerCombo.SelectedIndex = lowerCombo.FindString(Content.InclusiveLowerBound ? "True" : "False");
        upperCombo.SelectedIndex = upperCombo.FindString(Content.InclusiveUpperBound ? "True" : "False");
        derivationInput.Text = Content.IsDerivation ? "True" : "False";
        variableInput.Text = Content.Variable;
        numberderivationInput.Text = Content.NumberOfDerivation.ToString();
      }
      SetEnabledStateOfControls();
    }

    private void UpdateValues() {

    }
  }
}
